.. include:: ../../README.rst
  :end-before: end-of-intro

.. toctree::
  :maxdepth: 2

  installation
  usage

.. include:: ../../README.rst
  :start-after: beginning-of-test-server
  :end-before: end-of-test-server


API reference
-------------
If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 4

   api


mccli is developed on `Github <https://github.com/dianagudu/mccli>`_. Please report `issues <https://github.com/dianagudu/mccli/issues>`_ there as well.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

